@@ -9,6 +9,8 @@
 import configparser
 import pathlib
 
+from typing import Optional, Union
+
 import packaging.version
 
 from ._vendor import toml
@@ -17,13 +19,13 @@ from ._vendor import toml
 try:
     import importlib.metadata as importlib_metadata
 except ImportError:
-    import importlib_metadata
+    import importlib_metadata  # type: ignore
 
 
-METADATA_FILES = ['pyproject.toml', 'setup.cfg', 'setup.py']
+METADATA_FILES = ["pyproject.toml", "setup.cfg", "setup.py"]
 
 
-def get_metadata_files(path):
+def get_metadata_files(path: Union[str, pathlib.Path]) -> Union[str, None]:
     """Finds the list of metadata files for a package.
 
     Returns the path of the ``pyproject.toml``, ``setup.cfg``, or ``setup.py``
@@ -31,14 +33,13 @@ def get_metadata_files(path):
 
     Parameters
     ----------
-    path : str
+    path
         The path relative to which to search for metadata files.
 
     Returns
     -------
     path
         The path to the metadata file, or `None` if none was found.
-
     """
 
     path = pathlib.Path(path).absolute()
@@ -58,7 +59,11 @@ def get_metadata_files(path):
     return None
 
 
-def get_package_version(path=None, package_name=None, pep_440=False):
+def get_package_version(
+    path: Optional[str] = None,
+    package_name: Optional[str] = None,
+    pep_440: bool = False,
+) -> Union[str, None]:
     """Returns the version of a package.
 
     First tries to determine if a metadata file is available and parses it.
@@ -67,37 +72,37 @@ def get_package_version(path=None, package_name=None, pep_440=False):
 
     Parameters
     ----------
-    path : str
+    path
         The path relative to which to search for metadata files.
-    package_name : str
+    package_name
         The name of the package.
-    pep_440 : bool
+    pep_440
         If `True`, normalises the version string according to PEP 440.
 
     Returns
     -------
-    version : str
+    version
         The version string, or `None` if it cannot be found.
-
     """
 
-    assert path or package_name, 'either path or package_name are needed.'
+    assert path or package_name, "either path or package_name are needed."
 
-    version = None
+    version: Union[str, None] = None
 
     if path:
         metadata_file = get_metadata_files(path)
         if metadata_file:
-            if 'pyproject.toml' in str(metadata_file):
+            if "pyproject.toml" in str(metadata_file):
                 pyproject = toml.load(open(metadata_file))
-                if 'tool' in pyproject and 'poetry' in pyproject['tool']:
-                    version = pyproject['tool']['poetry']['version']
-            elif 'setup.cfg' in str(metadata_file):
+                if "tool" in pyproject and "poetry" in pyproject["tool"]:
+                    version = pyproject["tool"]["poetry"]["version"]
+            elif "setup.cfg" in str(metadata_file):
                 setupcfg = configparser.ConfigParser()
                 setupcfg.read(metadata_file)
-                if (setupcfg.has_section('metadata') and
-                        setupcfg.has_option('metadata', 'version')):
-                    version = setupcfg.get('metadata', 'version')
+                if setupcfg.has_section("metadata") and setupcfg.has_option(
+                    "metadata", "version"
+                ):
+                    version = setupcfg.get("metadata", "version")
 
     if package_name and not version:
         try:
@@ -108,4 +113,7 @@ def get_package_version(path=None, package_name=None, pep_440=False):
     if version and pep_440:
         version = str(packaging.version.Version(version))
 
-    return version
+    if isinstance(version, str):
+        return version
+    else:
+        return None
